<?php
include ("slooze_local.php");
page_open(array("sess" => "Tof_Session",
				"auth" => "Tof_Auth"));

$tof = new MySlooze($auth->auth['uid'],false);
require_once("actions/file_data.php");
$pictureID = $_REQUEST['PictureID'];
switch ($_REQUEST['Size']) {
	case 'thumb': 
		getFileData($tof,$pictureID,$tof->thumb_suffix);
		break;
	case 'full':
		getFileData($tof,$pictureID,$tof->orig_suffix);
		break;
	case 'medium': 
		getFileData($tof,$pictureID,$tof->picture_suffix);
		break;
}

// We do not close the page because of session concurrency issues:
// page_open may have read old values of session variables, and we must not save them
?>
